module Contents
  class Page < ActiveRecord::Base
    include Contents::RailsAdmin if defined?(RailsAdmin)

    belongs_to :superpage, class_name: 'Contents::Page', foreign_key: :contents_page_id
    has_many :subpages, class_name: 'Contents::Page', foreign_key: :contents_page_id

    before_save :set_layout, :set_template, :set_slug

    scope :orphans, -> { where(contents_page_id: nil) }

    def path
      path = [self.slug]
      page = self

      while page.superpage do
        path << page.superpage.slug
        page = page.superpage
      end

      path.reverse.join('/')
    end

    private

      def layouts_paths
        Rails.root.join('app', 'views', 'layouts')
      end

      def set_layout
        self.layout = 'application' if self.layout.empty?
      end

      def set_template
        self.template = 'application/index' if self.template.empty?
      end

      def set_slug
        self.slug = self.title.to_slug.transliterate.normalize if self.slug.empty?
      end
  end
end
